{ config, lib, pkgs, ... }:

{
  imports = [ ./hardware-configuration.nix ];

  # Bootloader stuff
  boot.loader.systemd-boot = { enable = true; };
  boot.loader.efi = { canTouchEfiVariables = true; };

  # Networking stuff
  networking.hostName = "prismo"; # Define your hostname.
  networking.networkmanager.enable = true;

  # Set time stuff
  time.timeZone = "Europe/Oslo";

  # Setup hyprland
  services.xserver.enable = true;
  programs.hyprland = {
    enable = true;
    xwayland.enable = true;
  };

  # Setup common XDG env vars
  environment.sessionVariables = rec {
    XDG_CACHE_HOME = "$HOME/.cache";
    XDG_CONFIG_HOME = "$HOME/.config";
    XDG_DATA_HOME = "$HOME/.local/share";
    XDG_STATE_HOME = "$HOME/.local/state";
    XDG_BIN_HOME = "$HOME/.local/bin";
    PATH = [ "${XDG_BIN_HOME}" ];
  };

  # Enable sudo
  security.sudo.enable = true;

  # Enable flakes
  nix.settings.experimental-features = [ "nix-command" "flakes" ];

  nixpkgs.config.allowUnfree = true;
  # Install system-wide packages
  environment.systemPackages = with pkgs; [
    vim
    wget
    curl
    alacritty
    greetd.tuigreet
    git
  ];

  # Do NOT change this value unless you have manually inspected all the changes it would make to your configuration,
  # and migrated your data accordingly.
  #
  # For more information, see `man configuration.nix` or https://nixos.org/manual/nixos/stable/options#opt-system.stateVersion .
  system.stateVersion = "23.11"; # Did you read the comment?
}

